import { jsx as _jsx } from "react/jsx-runtime";
import Markdown from 'react-markdown';
import remarkGfm from 'remark-gfm';
import { useClassName } from '../hooks/className';
import { useFireEvent } from '../events';
import { useCustomRender } from '../hooks/config';
import { CodeComp } from './Code';
const MarkdownComp = (props) => {
    const { text, codeStyle } = props;
    const components = {
        a({ children, href }) {
            return _jsx(MarkdownA, { href: href, children: children });
        },
        code({ children, className }) {
            return (_jsx(MarkdownCode, { className: className, codeStyle: codeStyle, children: children }));
        },
    };
    return (_jsx(Markdown, { className: useClassName(props), remarkPlugins: [remarkGfm], components: components, children: text }));
};
export default MarkdownComp;
const MarkdownA = ({ children, href }) => {
    const { fireEvent } = useFireEvent();
    let onClick;
    let preventDefault = true;
    if (!href) {
        href = '#';
    }
    else if (href === '!back') {
        href = '#';
        onClick = { type: 'back' };
    }
    else if (href.startsWith('!')) {
        onClick = { type: 'page', name: href.slice(1) };
        href = '#';
    }
    else if (href.startsWith('#')) {
        preventDefault = href.length === 1;
    }
    else {
        onClick = { type: 'go-to', url: href };
    }
    const clickHandler = (e) => {
        if (preventDefault) {
            e.preventDefault();
            fireEvent(onClick);
        }
    };
    return (_jsx("a", { href: href, onClick: clickHandler, children: children }));
};
const MarkdownCode = ({ children, className, codeStyle }) => {
    const match = /language-(\w+)/.exec(className || '');
    const language = match ? match[1] : undefined;
    const codeProps = {
        type: 'Code',
        text: String(children).replace(/\n$/, ''),
        language,
        codeStyle,
    };
    const CustomRenderComp = useCustomRender(codeProps);
    if (CustomRenderComp) {
        return _jsx(CustomRenderComp, {});
    }
    else {
        return _jsx(CodeComp, { ...codeProps });
    }
};
